aboutsummaryrefslogtreecommitdiffstats
path: root/mail/folder-browser.h
diff options
context:
space:
mode:
Diffstat (limited to 'mail/folder-browser.h')
-rw-r--r--mail/folder-browser.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/mail/folder-browser.h b/mail/folder-browser.h
index 848a312327..1b76f82c97 100644
--- a/mail/folder-browser.h
+++ b/mail/folder-browser.h
@@ -78,8 +78,8 @@ struct _FolderBrowser {
int sensitize_timeout_id;
int update_status_bar_idle_id;
- /* View collection and the menu handler object */
- GalViewCollection *view_collection;
+ /* View instance and the menu handler object */
+ GalViewInstance *view_instance;
GalViewMenus *view_menus;
GtkWidget *invisible;